@@ -65,6 +65,20 @@ class BaseAPITest(test_base.BaseTest):
 
 class TestApiIntrospect(BaseAPITest):
 
+    def test_root_endpoint_with_prefix(self):
+        res = self.app.get(
+            '/', headers={'X-Forwarded-Proto': 'https',
+                          'X-Forwarded-Host': 'myhost',
+                          'X-Forwarded-Prefix': '/ironic_inspector'})
+
+        self.assertEqual(200, res.status_code)
+        self.assertEqual('application/json',
+                         res.headers['content-type'])
+        cur_version = res.json['versions'][0]
+        hrefs = [link['href'] for link in cur_version['links']]
+        for href in hrefs:
+            self.assertTrue(href.startswith('https://myhost/ironic_inspector'))
+
     def test_introspect(self):
 
         res = self.app.post('/v1/introspection/%s' % self.uuid,
@@ -480,7 +494,7 @@ class TestApiReapply(BaseAPITest):
 
     @mock.patch.object(ir_utils, 'get_node', autospec=True)
     def test_reapply_with_node_name(self, get_mock):
-        get_mock.return_value = mock.Mock(uuid=self.uuid)
+        get_mock.return_value = mock.Mock(id=self.uuid)
         self.app.post('/v1/introspection/%s/data/unprocessed' %
                       'fake-node')
         self.client_mock.call.assert_called_once_with({}, 'do_reapply',
