@@ -21,7 +21,6 @@ from unittest import mock
 import automaton
 from openstack import exceptions as os_exc
 from oslo_config import cfg
-import oslo_db
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 
@@ -1051,11 +1050,6 @@ class TestNodeInfoState(test_base.NodeStateTest):
         row = db.model_query(db.Node).get(self.node_info.uuid)
         self.assertEqual(self.node_info.state, row.state)
 
-    def test_set_invalid_state(self):
-        self.assertRaisesRegex(oslo_db.exception.DBError,
-                               'constraint failed',
-                               self.node_info._set_state, 'foo')
-
     def test_commit(self):
         current_time = timeutils.utcnow()
         self.node_info.started_at = self.node_info.finished_at = current_time
@@ -1320,6 +1314,17 @@ class TestStartIntrospection(test_base.NodeTest):
                                self.node_info.uuid)
         self.assertFalse(add_node_mock.called)
 
+    @prepare_mocks
+    def test_ensure_start_on_error(self, fsm_event_mock,
+                                   add_node_mock):
+        def side_effect(*args):
+            self.node_info._state = istate.States.error
+
+        fsm_event_mock.side_effect = side_effect
+        node_cache.start_introspection(self.node.uuid)
+        add_node_mock.assert_called_once_with(self.node_info.uuid,
+                                              istate.States.starting)
+
 
 class TestIntrospectionDataDbStore(test_base.NodeTest):
     def setUp(self):
